@@ -2,6 +2,7 @@ from pydantic import BaseModel
 from hexbytes import HexBytes
 from typing import NewType
 from enum import Enum
+from typing import Any
 
 
 class EidasLevelEnum(Enum):
@@ -82,7 +83,7 @@ class DelegateCallValidator(BaseModel):
 
 
 class RunRawTransaction(BaseModel):
-    raw_transaction: Transaction
+    raw_transaction: Any
     network: NetworkValidator
 
     def get_dict(self) -> dict:
